==> nextcloud-29.0.14.tar.bz2: nextcloud/apps/photos/l10n/nl.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Openbare Link",
    "Photos" : "Foto's",
    "On This Day" : "Vandaag",
    "Your memories under your control" : "Jouw herinneringen onder jouw beheer",
    "All media" : "Alle media",
    "Videos" : "Videos",
    "Albums" : "Albums",
    "Collaborative albums" : "Gezamenlijke albums",
    "People" : "Mensen",
    "Folders" : "Mappen",
    "Favorites" : "Favorieten",
    "On this day" : "Op deze dag",
    "Shared with you" : "Met je gedeeld",
    "Tags" : "Tags",
    "Places" : "Locaties",
    "Map" : "Kaart",
    "Photos settings" : "Instellingen voor foto's",
    "Mark selection as favorite" : "Markeer selectie als favoriet",
    "Add selection to favorites" : "Selectie toevoegen aan favorieten",
    "Remove selection from favorites" : "Verwijder selectie uit favorieten",
    "Name of the album" : "Naam van het album",
    "Location of the album" : "Locatie van het album",
    "Back" : "Terug",
    "Add collaborators" : "Bijdragers toevoegen",
    "Save" : "Opslaan",
    "Create album" : "Maak album",
    "Add to Album" : "Toevoegen aan album",
    "Add selection to album {albumName}" : "Selectie toevoegen aan album {albumName}",
    "Shared by" : "Gedeeld door",
    "Create a new album." : "Maak een nieuw album.",
    "Create new album" : "Maak nieuw album",
    "New album" : "Nieuw album",
    "_%n item_::_%n photos and videos_" : ["%n item","%n foto's en video's"],
    "Failed to fetch collaborators list." : "Ophalen van bijdragerslijst is mislukt.",
    "Failed to update album." : "Bijwerken van album mislukt.",
    "Add people or groups who can edit your album" : "Voeg mensen of groepen toe die je album kunnen bewerken",
    "Search people or groups" : "Zoek mensen of groepen",
    "No recommendations. Start typing." : "Geen aanbevelingen. Begin te typen.",
    "Group" : "Groep",
    "Remove {collaboratorLabel} from the collaborators list" : "Verwijder {collaboratorLabel} van de bijdragerslijst",
    "Copy the public link" : "Kopieer de openbare link",
    "Public link copied!" : "Openbare link gekopieerd!",
    "Copy public link" : "Kopieer openbare link",
    "Delete the public link" : "Verwijder de openbare link",
    "Create public link share" : "Openbare link delen",
    "Share via public link" : "Deel via openbare link",
    "This collection does not exist" : "Deze verzameling bestaat niet",
    "An error occurred" : "Er heeft een fout opgetreden",
    "No picture for this day" : "Geen plaatje voor deze dag",
    "Picture taken on this day will show up here." : "Plaatje gemaakt op deze dag wordt ghier getoond",
    "More photos from this day" : "Meer foto's van deze dag",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n ongekende foto's","%n niet-toegewezen foto's"],
    "Favorite" : "Favoriet",
    "Favorite image, open the full size \"{name}\" image" : "Favoriet plaatje, open het plaatje \"¨{name}\" in volledige grootte",
    "Open the full size \"{name}\" image" : "Open het \"{name}\" beeld in originele grootte",
    "Select image {imageName}" : "Selecteer afbeelding {imageName}",
    "Open the \"{name}\" folder" : "Open de \"{name}\" map",
    "Back to {folder}" : "Terug naar {folder}",
    "Go back" : "Ga terug",
    "Share this folder" : "Deze map delen",
    "Dates" : "Data",
    "Jump to specific date in list" : "Spring naar de gespecificeerde datum in de lijst",
    "Jump to {date}" : "Spring naar {date}",
    "Add to {destination}" : "Toevoegen aan {destination}",
    "The destination folder is owned by {owner}" : "De doelmap is eigendom van {owner}",
    "There are no photos or videos yet!" : "Er zijn nog geen foto's of video's!",
    "_{years} year ago_::_{years} years ago_" : ["{years} jaar geleden","{years} jaren geleden"],
    "Enable squared photos view" : "Inschakelen vierkante foto overzicht",
    "Delete source directory" : "Verwijder bronmap",
    "Select a source folder for your media" : "Selecteer een bronmap voor je media",
    "All folders" : "Alle mappen",
    "Add a Photos source for the timelines" : "Voeg een Foto-bron toe voor de tijdlijnen",
    "Add folder" : "Map toevoegen",
    "Select the default upload location for your media" : "Selecteer de standaard uploadlocatie voor je media",
    "Home" : "Startpagina",
    "Choose default Photos upload and Albums location" : "Kies de standaardlocatie voor het uploaden van foto's en albums.",
    "Choose a different folder" : "Kies een andere map",
    "View" : "Bekijken",
    "Media folders" : "Mediamappen",
    "Choose the folders from where photos and videos are shown." : "Kies de mappen van waaruit foto's en video's getoond worden.",
    "Upload folder" : "Uploadmap",
    "Choose the folder where photos and albums are uploaded to." : "Kies de mappen waar foto's en video's naar geüpload worden.",
    "_%n photo_::_%n photos_" : ["%n foto","%n foto's"],
    "Unselect all" : "Alle deselecteren",
    "Add photos to this album" : "Foto's toevoegen aan dit album",
    "Manage collaborators for this album" : "Beheer bijdragers voor dit album",
    "Open actions menu" : "Actiemenu openen",
    "Edit album details" : "Bewerk albumdetails",
    "Download all files in album" : "Download alle bestanden in album",
    "Delete album" : "Album verwijderen",
    "Download selected files" : "Geselecteerde bestanden downloaden",
    "Remove selection from album" : "Verwijder selectie uit album",
    "This album does not have any photos or videos yet!" : "Dit album heeft nog geen foto's of video's!",
    "Add photos to {albumName}" : "Voeg foto's toe aan {albumName}",
    "Manage collaborators" : "Beheer bijdragers",
    "Save collaborators for this album." : "Bewaar bijdragers voor dit album.",
    "Cover photo for album {albumName}" : "Omslagfoto voor album {albumName}",
    "There is no album yet!" : "Er is nog geen album!",
    "This person could not be found" : "Deze persoon kon niet worden gevonden",
    "Rename person" : "Hernoem persoon",
    "Merge with different person" : "Samenvoegen met ander persoon",
    "Download selected photos" : "Download geselecteerde foto's",
    "Remove from favorites" : "Verwijder uit favorieten",
    "Remove person" : "Verwijder persoon",
    "Name of this person" : "Naam van deze persoon",
    "Save." : "Opslaan.",
    "Merge person" : "Persoon samenvoegen",
    "Move to different person" : "Verplaats naar een ander persoon",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Verplaats foto naar een ander persoon","Verplaats foto's naar een ander persoon"],
    "_Remove photo from person_::_Remove photos from person_" : ["Verwijder foto van persoon","Verwijder foto's van persoon"],
    "This might take some time depending on the size of your photo library." : "Dit kan enige tijd duren afhankelijk van de grootte van je fotobibliotheek.",
    "Recognized people will show up here" : "Herkende personen zullen hier verschijnen",
    "This folder does not exist" : "Deze map bestaat niet",
    "Loading folders …" : "Mappen laden ...",
    "No photos in here" : "Geen foto's hier",
    "Taken on {date} at {time}" : "Genomen op {date} om {time}",
    "This place does not have any photos or videos yet!" : "Deze plek heeft nog geen foto's of video's!",
    "Add photos to this place" : "Foto's toevoegen aan deze plek",
    "Cover photo for place {placeName}" : "Coverfoto voor plaats {placeName}",
    "There is no place yet!" : "Er is nog geen locatie!",
    "Cover photo for shared album {albumName}." : "Omslagfoto voor gedeeld album {albumName}.",
    "Back to tags overview" : "Terug naar het overzicht van tags",
    "No photos with this tag yet" : "Nog geen foto's met deze tag",
    "No tags yet" : "Nog geen labels",
    "Photos with tags will show up here" : "Gelabelde foto's worden hier getoond",
    "Popular tags" : "Populaire tags",
    "All tags" : "Alle tags",
    "One of the source folders does not exist" : "Een van de bronmappen bestaat niet",
    "Add to album" : "Toevoegen aan album",
    "Delete selection" : "Verwijder selectie",
    "No photos or videos in here" : "Geen foto's of video's hier",
    "Unassigned faces" : "Niet toegewezen gezichten",
    "_%n photos_::_%n photos_" : ["%n foto","%n foto's"],
    "Failed to fetch collection." : "Niet gelukt om de collectie op te halen.",
    "Failed to fetch collections list." : "Niet gelukt om de lijst met collecties op te halen.",
    "Failed to fetch faces list." : "Ophalen van lijst met gezichten mislukt.",
    "All your media" : "Al je media",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Gedeelde albums",
    "Shared album {title}" : "Gedeeld album {title}",
    "Public album {title}" : "Openbaar album {title}",
    "Tagged photos" : "Gelabelde foto's",
    "Tagged photo {title}" : "Tagged foto {title}",
    "{title}'s face" : "gezicht van {title}",
    "{startDate} to {endDate}" : "{startDate} tot {endDate}",
    "Details" : "Details",
    "Failed to rename {oldName} to {faceName}." : "Hernoemen van {oldName} naar {faceName} mislukt.",
    "Failed to delete {faceName}." : "Verwijderen van {faceName} mislukt.",
    "Failed to delete {fileId}." : "Verwijderen van {fileId} mislukt.",
    "Failed to delete {fileName}." : "Verwijderen van {fileName} mislukt.",
    "Failed to set favorite state for {fileId}." : "Favorietenstatus instellen voor {fileId} mislukt.",
    "Failed to set favorite state for {fileName}." : "Favorietenstatus instellen voor {fileName} mislukt.",
    "Could not load photos folder" : "Kon de fotomap niet laden",
    "One of the source folders does not exists" : "Een van de bronmappen bestaat niet",
    "Add" : "Toevoegen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.11.tar.bz2: nextcloud/apps/photos/l10n/nl.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Openbare Link",
    "Photos" : "Foto's",
    "On This Day" : "Vandaag",
    "Your memories under your control" : "Jouw herinneringen onder jouw beheer",
    "All media" : "Alle media",
    "Videos" : "Videos",
    "Albums" : "Albums",
    "Collaborative albums" : "Gezamenlijke albums",
    "People" : "Mensen",
    "Folders" : "Mappen",
    "Favorites" : "Favorieten",
    "On this day" : "Op deze dag",
    "Shared with you" : "Met je gedeeld",
    "Tags" : "Tags",
    "Places" : "Locaties",
    "Map" : "Kaart",
    "Photos settings" : "Instellingen voor foto's",
    "Mark selection as favorite" : "Markeer selectie als favoriet",
    "Add selection to favorites" : "Selectie toevoegen aan favorieten",
    "Remove selection from favorites" : "Verwijder selectie uit favorieten",
    "Name of the album" : "Naam van het album",
    "Location of the album" : "Locatie van het album",
    "Back" : "Terug",
    "Add collaborators" : "Bijdragers toevoegen",
    "Save" : "Opslaan",
    "Create album" : "Maak album",
    "Add to Album" : "Toevoegen aan album",
    "Add selection to album {albumName}" : "Selectie toevoegen aan album {albumName}",
    "Shared by" : "Gedeeld door",
    "Create a new album." : "Maak een nieuw album.",
    "Create new album" : "Maak nieuw album",
    "New album" : "Nieuw album",
    "_%n item_::_%n photos and videos_" : ["%n item","%n foto's en video's"],
    "Failed to fetch collaborators list." : "Ophalen van bijdragerslijst is mislukt.",
    "Failed to update album." : "Bijwerken van album mislukt.",
    "Add people or groups who can edit your album" : "Voeg mensen of groepen toe die je album kunnen bewerken",
    "Search people or groups" : "Zoek mensen of groepen",
    "No recommendations. Start typing." : "Geen aanbevelingen. Begin te typen.",
    "Group" : "Groep",
    "Remove {collaboratorLabel} from the collaborators list" : "Verwijder {collaboratorLabel} van de bijdragerslijst",
    "Copy the public link" : "Kopieer de openbare link",
    "Public link copied!" : "Openbare link gekopieerd!",
    "Copy public link" : "Kopieer openbare link",
    "Delete the public link" : "Verwijder de openbare link",
    "Create public link share" : "Openbare link delen",
    "Share via public link" : "Deel via openbare link",
    "This collection does not exist" : "Deze verzameling bestaat niet",
    "An error occurred" : "Er heeft een fout opgetreden",
    "No picture for this day" : "Geen afbeelding voor deze dag",
    "Picture taken on this day will show up here." : "Afbeelding gemaakt op deze dag wordt hier getoond",
    "More photos from this day" : "Meer foto's van deze dag",
    "_%n photos_::_%n photos_" : ["%n foto","%n foto's"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n ongekende foto's","%n niet-toegewezen foto's"],
    "Favorite" : "Favoriet",
    "Favorite image, open the full size \"{name}\" image" : "Favoriete afbeelding, open de afbeelding \"{name}\" in volledige grootte",
    "Open the full size \"{name}\" image" : "Open het \"{name}\" beeld in originele grootte",
    "Select image {imageName}" : "Selecteer afbeelding {imageName}",
    "Open the \"{name}\" folder" : "Open de \"{name}\" map",
    "Back to {folder}" : "Terug naar {folder}",
    "Go back" : "Ga terug",
    "Share this folder" : "Deze map delen",
    "Dates" : "Data",
    "Jump to specific date in list" : "Spring naar de gespecificeerde datum in de lijst",
    "Jump to {date}" : "Spring naar {date}",
    "Add to {destination}" : "Toevoegen aan {destination}",
    "The destination folder is owned by {owner}" : "De doelmap is eigendom van {owner}",
    "There are no photos or videos yet!" : "Er zijn nog geen foto's of video's!",
    "_{years} year ago_::_{years} years ago_" : ["{years} jaar geleden","{years} jaren geleden"],
    "Enable squared photos view" : "Inschakelen vierkante foto overzicht",
    "Delete source directory" : "Verwijder bronmap",
    "Select a source folder for your media" : "Selecteer een bronmap voor je media",
    "All folders" : "Alle mappen",
    "Add a Photos source for the timelines" : "Voeg een Foto-bron toe voor de tijdlijnen",
    "Add folder" : "Map toevoegen",
    "Select the default upload location for your media" : "Selecteer de standaard uploadlocatie voor je media",
    "Home" : "Startpagina",
    "Choose default Photos upload and Albums location" : "Kies de standaardlocatie voor het uploaden van foto's en albums.",
    "Choose a different folder" : "Kies een andere map",
    "View" : "Bekijken",
    "Media folders" : "Mediamappen",
    "Choose the folders from where photos and videos are shown." : "Kies de mappen van waaruit foto's en video's getoond worden.",
    "Upload folder" : "Uploadmap",
    "Choose the folder where photos and albums are uploaded to." : "Kies de mappen waar foto's en video's naar geüpload worden.",
    "_%n photo_::_%n photos_" : ["%n foto","%n foto's"],
    "Unselect all" : "Alle deselecteren",
    "Add photos to this album" : "Foto's toevoegen aan dit album",
    "Manage collaborators for this album" : "Beheer bijdragers voor dit album",
    "Open actions menu" : "Actiemenu openen",
    "Edit album details" : "Bewerk albumdetails",
    "Download all files in album" : "Download alle bestanden in album",
    "Delete album" : "Album verwijderen",
    "Download selected files" : "Geselecteerde bestanden downloaden",
    "Remove selection from album" : "Verwijder selectie uit album",
    "This album does not have any photos or videos yet!" : "Dit album heeft nog geen foto's of video's!",
    "Add photos to {albumName}" : "Voeg foto's toe aan {albumName}",
    "Manage collaborators" : "Beheer bijdragers",
    "Save collaborators for this album." : "Bewaar bijdragers voor dit album.",
    "Cover photo for album {albumName}" : "Omslagfoto voor album {albumName}",
    "There is no album yet!" : "Er is nog geen album!",
    "This person could not be found" : "Deze persoon kon niet worden gevonden",
    "Rename person" : "Hernoem persoon",
    "Merge with different person" : "Samenvoegen met ander persoon",
    "Download selected photos" : "Download geselecteerde foto's",
    "Remove from favorites" : "Verwijder uit favorieten",
    "Remove person" : "Verwijder persoon",
    "Name of this person" : "Naam van deze persoon",
    "Save." : "Opslaan.",
    "Merge person" : "Persoon samenvoegen",
    "Move to different person" : "Verplaats naar een ander persoon",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Verplaats foto naar een ander persoon","Verplaats foto's naar een ander persoon"],
    "_Remove photo from person_::_Remove photos from person_" : ["Verwijder foto van persoon","Verwijder foto's van persoon"],
    "This might take some time depending on the size of your photo library." : "Dit kan enige tijd duren afhankelijk van de grootte van je fotobibliotheek.",
    "Recognized people will show up here" : "Herkende personen zullen hier verschijnen",
    "This folder does not exist" : "Deze map bestaat niet",
    "Loading folders …" : "Mappen laden ...",
    "No photos in here" : "Geen foto's hier",
    "Taken on {date} at {time}" : "Genomen op {date} om {time}",
    "This place does not have any photos or videos yet!" : "Deze plek heeft nog geen foto's of video's!",
    "Add photos to this place" : "Foto's toevoegen aan deze plek",
    "Cover photo for place {placeName}" : "Coverfoto voor plaats {placeName}",
    "There is no place yet!" : "Er is nog geen locatie!",
    "Back to tags overview" : "Terug naar het overzicht van tags",
    "No photos with this tag yet" : "Nog geen foto's met deze tag",
    "No tags yet" : "Nog geen labels",
    "Photos with tags will show up here" : "Gelabelde foto's worden hier getoond",
    "Popular tags" : "Populaire tags",
    "All tags" : "Alle tags",
    "One of the source folders does not exist" : "Een van de bronmappen bestaat niet",
    "Add to album" : "Toevoegen aan album",
    "Delete selection" : "Verwijder selectie",
    "No photos or videos in here" : "Geen foto's of video's hier",
    "Unassigned faces" : "Niet toegewezen gezichten",
    "Failed to fetch collection." : "Niet gelukt om de collectie op te halen.",
    "Failed to fetch collections list." : "Niet gelukt om de lijst met collecties op te halen.",
    "Failed to fetch faces list." : "Ophalen van lijst met gezichten mislukt.",
    "All your media" : "Al je media",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Gedeelde albums",
    "Shared album {title}" : "Gedeeld album {title}",
    "Public album {title}" : "Openbaar album {title}",
    "Tagged photos" : "Gelabelde foto's",
    "Tagged photo {title}" : "Tagged foto {title}",
    "{title}'s face" : "gezicht van {title}",
    "{startDate} to {endDate}" : "{startDate} tot {endDate}",
    "Details" : "Details",
    "Could not load photos folder" : "Kon de fotomap niet laden",
    "One of the source folders does not exists" : "Een van de bronmappen bestaat niet",
    "Add" : "Toevoegen"
},
"nplurals=2; plural=(n != 1);");
